==> wpewebkit_2.38.6.orig.tar.xz: wpewebkit-2.38.6/Source/WebCore/dom/CDATASection.cpp <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2003-2018 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "CDATASection.h"

#include "Document.h"
#include <wtf/IsoMallocInlines.h>

namespace WebCore {

WTF_MAKE_ISO_ALLOCATED_IMPL(CDATASection);

inline CDATASection::CDATASection(Document& document, String&& data)
    : Text(document, WTFMove(data), CreateText)
{
}

Ref<CDATASection> CDATASection::create(Document& document, String&& data)
{
    return adoptRef(*new CDATASection(document, WTFMove(data)));
}

String CDATASection::nodeName() const
{
    return "#cdata-section"_s;
}

Node::NodeType CDATASection::nodeType() const
{
    return CDATA_SECTION_NODE;
}

Ref<Node> CDATASection::cloneNodeInternal(Document& targetDocument, CloningOperation)
{
    return create(targetDocument, String { data() });
}

bool CDATASection::childTypeAllowed(NodeType) const
{
    return false;
}

Ref<Text> CDATASection::virtualCreate(String&& data)
{
    return create(document(), WTFMove(data));
}

} // namespace WebCore

==> wpewebkit_2.50.2.orig.tar.xz: wpewebkit-2.50.2/Source/WebCore/dom/CDATASection.cpp <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 * Copyright (C) 2003-2018 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "CDATASection.h"

#include "Document.h"
#include "DocumentInlines.h"
#include "SerializedNode.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_OR_ISO_ALLOCATED_IMPL(CDATASection);

inline CDATASection::CDATASection(Document& document, String&& data)
    : Text(document, WTFMove(data), CDATA_SECTION_NODE, { })
{
}

Ref<CDATASection> CDATASection::create(Document& document, String&& data)
{
    return adoptRef(*new CDATASection(document, WTFMove(data)));
}

String CDATASection::nodeName() const
{
    return "#cdata-section"_s;
}

Ref<Node> CDATASection::cloneNodeInternal(Document& document, CloningOperation, CustomElementRegistry*) const
{
    return create(document, String { data() });
}

SerializedNode CDATASection::serializeNode(CloningOperation) const
{
    return { SerializedNode::CDATASection { data() } };
}

Ref<Text> CDATASection::virtualCreate(String&& data)
{
    return create(protectedDocument(), WTFMove(data));
}

} // namespace WebCore
